/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002-2006  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <config.h>
#include <string>
extern "C" {
  #include <glib.h>
  #include <glib/gi18n.h>
};
#include <pan/general/log.h>
#include "url.h"

using namespace pan;

void
pan ::  pan_url_show (const Prefs& prefs, const char * url)
{
  g_return_if_fail (url && *url);

  std::string tmp;
  if (!strstr (url, "://") && strstr (url, "www"))
    tmp = std::string("http://") + url;
  else if (!strstr (url, "://") && strchr (url, '@') && !strstr(url,"mailto:"))
    tmp = std::string("mailto:") + url;
  else
    tmp = url;

  std::string browser;
  const std::string browser_mode (prefs.get_string ("browser", "use-custom-browser"));
       if (browser_mode == "gnome")   browser = "gnome-open";
  else if (browser_mode == "kde")     browser = "kfmclient exec";
  else if (browser_mode == "mac")     browser = "open";
  else if (browser_mode == "windows") browser = "start \"\"";
  else                                browser = prefs.get_string ("custom-browser", "firefox");

  std::string::size_type pos;
  if (browser.find("%s") == std::string::npos)
    browser += std::string(" ") + url;
  else while (((pos = browser.find ("%s"))) != std::string::npos)
    browser.replace (pos, 2, url);
  while (((pos = browser.find ("%%"))) != std::string::npos)
    browser.replace (pos, 2, "%");
  //std::cerr << LINE_ID << " browser command is [" << browser << ']' << std::endl;

  GError * err (0);
  g_spawn_command_line_async (browser.c_str(), &err);
  if (err != NULL) {
    Log::add_err_va (_("Error spawning browser: %s (Command was: %s)"), err->message, browser.c_str());
    g_clear_error (&err);
  }
}
